customerExp: Customer's job size and patience Provides with a realization...

View source: R/simulation.R

customerExpR Documentation

Customer's job size and patience Provides with a realization of Y~Exp(theta) and B~Gamma(eta,mu)

Description

Customer's job size and patience Provides with a realization of Y~Exp(theta) and B~Gamma(eta,mu)

Usage

customerExp(params)

Arguments

params

named list of parameters (output of 'listParams()').

Value

list with elements 'Patience' and 'Jobsize'

Examples

params <- listParams(gamma=10,lambda_0=20,theta=2.5, eta = 1, mu = 1 , s = 3)
 customer <- customerExp(params)
 customer

blebedenko/impatience2 documentation built on April 10, 2022, 11:01 a.m.