| grad | R Documentation |
generic gradient function
grad(point, params, AWX)
point |
named vector of 2-3 of parameters (gamma,lambda_0,theta) |
params |
the actual parameter values |
AWX |
the dataset |
a named vector with the value of the gradient at point, assuming the unspecified parameter is known!
params <- exampleParams()
names(GL0T(params))
AWX <- exampleDataAWX()
point <- GL0T(params)[c("lambda_0","theta")]
grad(point = point,AWX = AWX,params = params)
point <- GL0T(params)[c("lambda_0","gamma")]
grad(point = point,AWX = AWX,params = params)
point <- GL0T(params)[c("gamma","lambda_0")]
grad(point = point,AWX = AWX,params = params)
point <- GL0T(params) + runif(3)
grad(point = point,AWX = AWX,params = params)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.