makeAWXDirectories: Interactive function that creates an entire scenario

View source: R/simulation.R

makeAWXDirectoriesR Documentation

Interactive function that creates an entire scenario

Description

Interactive function that creates an entire scenario

Usage

makeAWXDirectories()

Details

User is prompted for the parameters in the console.

Value

Returns NULL. Creates folders with the realizations for each value of s.


blebedenko/impatience2 documentation built on April 10, 2022, 11:01 a.m.