negLogLik: (negative) mean log-likelihood for the sinusoidal arrivals...

View source: R/likelihood.R

negLogLikR Documentation

(negative) mean log-likelihood for the sinusoidal arrivals model The mean is returned instead of the sum - should help gradient based optimizers

Description

(negative) mean log-likelihood for the sinusoidal arrivals model The mean is returned instead of the sum - should help gradient based optimizers

Usage

negLogLik(gamma, lambda_0, theta, AWX)

Arguments

gamma

periodical component of rate function

lambda_0

constant component of rate function

theta

parameter of exponential patience

AWX

compact simulation results for memory economy (A,W,X).

Value

The negative log-likelihood at the point provided. Based on mean (instead of sum).


blebedenko/impatience2 documentation built on April 10, 2022, 11:01 a.m.