oneKnownLik: Function factory for partial likelihoods

View source: R/likelihood.R

oneKnownLikR Documentation

Function factory for partial likelihoods

Description

Function factory for partial likelihoods

Usage

oneKnownLik(which_known, params, AWX)

Arguments

which_known

Which of the parameter values is known to the estimator? "theta", "gamma" or "lambda_0".

params

vector c(gamma, lambda_0, theta)

AWX

data

Value

a function that computes likelihood for the remaining two parameter except which_known. The function's input is always a vector where the parameters are ordered alphabetically by their names, gamma before lambda_0 before theta.

Examples

params <- exampleParams()
AWX <- resSimAWX(4,params)
f <- oneKnownLik("theta",params = params,AWX = AWX)
f(c(1,2)) # likelihood for gamma = 1 lambda_0 = 2

blebedenko/impatience2 documentation built on April 10, 2022, 11:01 a.m.