pltQueueInterval: Plot the queue dynamics in a specified time interval

pltQueueIntervalR Documentation

Plot the queue dynamics in a specified time interval

Description

Plot the queue dynamics in a specified time interval

Usage

pltQueueInterval(from_to = c(1, 2), RES, params)

Arguments

from_to

vector of start and stop of the time interval. Defaults to c(1,2).

RES

full simulations results list

params

scenario parameters

Value

plot only

Examples

R <- exampleDataRES()
pltQueueInterval(RES = R, params = exampleParams())

blebedenko/impatience2 documentation built on April 10, 2022, 11:01 a.m.