twoKnownLik: Function factory for partial likelihoods

View source: R/likelihood.R

twoKnownLikR Documentation

Function factory for partial likelihoods

Description

Function factory for partial likelihoods

Usage

twoKnownLik(which_not_known, params, AWX)

Arguments

which_not_known

name of the UNKNOWN parameter to be estimated

params

list of parameters

AWX

AWX dataframe

Value

a function that computes likelihood for the the parameter which_not_known. The function's input is always a vector where the parameters are ordered alphabetically by their names, gamma before lambda_0 before theta.


blebedenko/impatience2 documentation built on April 10, 2022, 11:01 a.m.