| makeAWXDirectories | R Documentation |
Interactive function that creates an entire scenario
makeAWXDirectories()
User is prompted for the parameters in the console.
Returns NULL. Creates folders with the realizations for each value of s.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.