| twoKnownLik | R Documentation |
Function factory for partial likelihoods
twoKnownLik(which_not_known, params, AWX)
which_not_known |
name of the UNKNOWN parameter to be estimated |
params |
list of parameters |
AWX |
AWX dataframe |
a function that computes likelihood for the the parameter which_not_known. The function's input is always a vector where the parameters are ordered alphabetically by their names, gamma before lambda_0 before theta.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.